Friendly Public Transport Format (FPTF)
=======================================

Most types used in pyHaFAS are specified in the `Friendly Public Transport Format <https://github.com/public-transport/friendly-public-transport-format/blob/master/spec/readme.md>`_.
With this specification, we build python classes in the module `pyhafas.types.fptf`. You can find the reference for those classes below.

.. automodule:: pyhafas.types.fptf
   :members:
   :undoc-members:
   :show-inheritance:
